@@ -22,7 +22,12 @@ __author_email__ = "kouki.sergey@gmail.com, ekanerina@yandex.ru"
 # Импорт основных классов
 
 from .basic_stats import BasicStats
-from .components import BasicStatsComponent, MorphStatsComponent, ReadabilityStatsComponent
+from .components import (
+    BasicStatsComponent,
+    DiversityStatsComponent,
+    MorphStatsComponent,
+    ReadabilityStatsComponent
+)
 from .diversity_stats import DiversityStats
 from .extractors import SentsExtractor, WordsExtractor
 from .morph_stats import MorphStats
